@@ -8,6 +8,10 @@ use warnings;
 
 use base 'Exception::Tiny';
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
+
+sub data {
+    return shift->{data};
+}
 
 1;
