@@ -28,7 +28,7 @@ use Hash::Merge::Simple 'merge';
 
 use base 'Exporter::Tiny';
 
-our $VERSION = '0.12'; # VERSION
+our $VERSION = '0.13'; # VERSION
 
 
 our $EXTS = {
@@ -44,27 +44,27 @@ our $EXTS = {
     UNIVERSAL => 'Bubblegum::Object::Universal',
 };
 
-my %TYPES = (
-    ArrayRef   => ['aref', 'arrayref'],
-    Bool       => ['bool', 'boolean'],
-    ClassName  => ['class', 'classname'],
-    CodeRef    => ['cref', 'coderef'],
-    Defined    => ['def', 'defined'],
-    FileHandle => ['fh', 'filehandle'],
-    GlobRef    => ['glob', 'globref'],
-    HashRef    => ['href', 'hashref'],
-    Int        => ['int', 'integer'],
-    Num        => ['num', 'number'],
-    Object     => ['obj', 'object'],
-    Ref        => ['ref', 'reference'],
-    RegexpRef  => ['rref', 'regexpref'],
-    ScalarRef  => ['sref', 'scalarref'],
-    Str        => ['str', 'string'],
-    Undef      => ['nil', 'null', 'undef', 'undefined'],
-    Value      => ['val', 'value'],
-);
+my $TYPES = {
+    ArrayRef   => [qw(aref arrayref)],
+    Bool       => [qw(bool boolean)],
+    ClassName  => [qw(class classname)],
+    CodeRef    => [qw(cref coderef)],
+    Defined    => [qw(def defined)],
+    FileHandle => [qw(fh filehandle)],
+    GlobRef    => [qw(glob globref)],
+    HashRef    => [qw(href hashref)],
+    Int        => [qw(int integer)],
+    Num        => [qw(num number)],
+    Object     => [qw(obj object)],
+    Ref        => [qw(ref reference)],
+    RegexpRef  => [qw(rref regexpref)],
+    ScalarRef  => [qw(sref scalarref)],
+    Str        => [qw(str string)],
+    Undef      => [qw(nil null undef undefined)],
+    Value      => [qw(val value)],
+};
 
-our @EXPORT_OK = qw(
+my @UTILS = qw(
     cwd
     date
     date_epoch
@@ -74,8 +74,8 @@ our @EXPORT_OK = qw(
     find
     here
     home
-    merge
     load
+    merge
     path
     quote
     raise
@@ -86,13 +86,16 @@ our @EXPORT_OK = qw(
     which
     will
 );
+
+our @EXPORT_OK = @UTILS;
+
 our %EXPORT_TAGS = (
     attr => sub {
+        no strict 'refs';
+        no warnings 'redefine';
         my $args    = pop;
         my $target  = $args->{into};
         my $builder = $target->can('has') or return;
-        no strict 'refs';
-        no warnings 'redefine';
         *{"${target}::has"} = sub {
             my $type    = shift if isa_coderef($_[0]);
             my $names   = isa_aref($_[0]) ? $_[0] : [$_[0]];
@@ -113,36 +116,23 @@ our %EXPORT_TAGS = (
         };
         return;
     },
+    minimal => sub {
+        no strict 'refs';
+        my $class = shift;
+        my $name  = 'EXPORT_TAGS';
+        my $tags  = \%{"${class}::${name}"};
+        $tags->{attr}->(@_);
+        return @{$tags->{constraints}}, @{$tags->{isas}}, @{$tags->{nots}};
+    },
     utils => sub {
-        return qw(
-            cwd
-            date
-            date_epoch
-            date_format
-            dump
-            file
-            find
-            here
-            home
-            merge
-            load
-            path
-            quote
-            raise
-            script
-            unquote
-            user
-            user_info
-            which
-            will
-        )
+        return @UTILS;
     }
 );
 {
     no strict 'refs';
     my $package  = __PACKAGE__;
     my $compiler = Type::Params->can('compile');
-    while (my($class, $names) = each %TYPES) {
+    while (my($class, $names) = each %{$TYPES}) {
         my $validator  = Types::Standard->can($class);
         my $validation = $compiler->($validator->());
         for my $name (@{$names}) {
@@ -195,6 +185,15 @@ our %EXPORT_TAGS = (
                     return $validation;
                 };
             }
+            # generate for constraints
+            {
+                push @EXPORT_OK, "_$name";
+                push @{$EXPORT_TAGS{constraints}}, "_$name";
+                *{"${package}::_${name}"} = sub (;*) {
+                    return $package->can("typeof_$name") if !@_;
+                    goto   $package->can("type_$name");
+                };
+            }
         }
     }
 }
@@ -268,6 +267,7 @@ sub load {
 }
 
 
+
 sub path {
     return Path::Tiny::path(@_);
 }
@@ -283,7 +283,7 @@ sub quote {
 
 sub raise {
     my $class = 'Bubblegum::Exception';
-    @_ = ($class, message => shift, data => shift // {});
+    @_ = ($class, message => shift, data => shift);
     goto $class->can('throw');
 }
 
@@ -343,24 +343,23 @@ Bubblegum::Syntax - Common Helper Functions for Structuring Applications
 
 =head1 VERSION
 
-version 0.12
+version 0.13
 
 =head1 SYNOPSIS
 
     package Server;
 
     use Bubblegum::Class;
-    use Bubblegum::Syntax -attr, -typesof;
+    use Bubblegum::Syntax -minimal;
 
-    has typeof_obj, 'config';
+    has _hashref, 'config';
 
     package main;
 
     use Bubblegum;
-    use Bubblegum::Syntax -isas, -utils;
+    use Bubblegum::Syntax qw(file);
 
-    my $data   = file('/tmp/config')->slurp;
-    my $config = $data->yaml->decode if isa_str $data;
+    my $config = file('/tmp/config')->slurp->yaml->decode;
     my $server = Server->new(config => $config);
 
 =head1 DESCRIPTION
@@ -442,6 +441,14 @@ The load function uses L<Class::Load> to require modules at runtime.
 
     my $class = load 'Test::Automata';
 
+=head2 merge
+
+The merge function uses L<Hash::Merge::Simple> to merge multi hash references
+into a single hash reference. Please view the L<Hash::Merge::Simple>
+documentation for example usages.
+
+    my $hash = merge $hash_a, $hash_b, $hash_c;
+
 =head2 path
 
 The path function returns a L<Path::Tiny> instance for operating on the
@@ -576,11 +583,162 @@ is the equivalent of:
         default => sub {}
     );
 
+=head2 -contraints
+
+The constraints export group exports all functions which have the C<_> prefix
+and provides functionality similar to importing the L</-attr>, L</-types> and
+L</-typesof> export groups except that the functions it emits are abbreviated
+multi-purpose versions of the functions emitted by the -types and -typesof
+export groups. These functions take a single argument and perform fatal type
+checking, or, if invoked with no arguments returns a code reference to the fatal
+type checking routine. The following is a list of functions exported by this
+group:
+
+=over 4
+
+=item *
+
+_aref
+
+=item *
+
+_arrayref
+
+=item *
+
+_bool
+
+=item *
+
+_boolean
+
+=item *
+
+_class
+
+=item *
+
+_classname
+
+=item *
+
+_cref
+
+=item *
+
+_coderef
+
+=item *
+
+_def
+
+=item *
+
+_defined
+
+=item *
+
+_fh
+
+=item *
+
+_filehandle
+
+=item *
+
+_glob
+
+=item *
+
+_globref
+
+=item *
+
+_href
+
+=item *
+
+_hashref
+
+=item *
+
+_int
+
+=item *
+
+_integer
+
+=item *
+
+_num
+
+=item *
+
+_number
+
+=item *
+
+_obj
+
+=item *
+
+_object
+
+=item *
+
+_ref
+
+=item *
+
+_reference
+
+=item *
+
+_rref
+
+=item *
+
+_regexpref
+
+=item *
+
+_sref
+
+=item *
+
+_scalarref
+
+=item *
+
+_str
+
+=item *
+
+_string
+
+=item *
+
+_nil
+
+=item *
+
+_null
+
+=item *
+
+_undef
+
+=item *
+
+_undefined
+
+=back
+
 =head2 -isas
 
 The isas export group exports all functions which have the C<isa_> prefix. These
 functions take a single argument and perform non-fatal type checking and return
-true or false. The follow is a list of functions exported by this group:
+true or false. The following is a list of functions exported by this group:
 
 =over 4
 
@@ -722,11 +880,18 @@ isa_undefined
 
 =back
 
+=head2 -minimal
+
+The minimal export group is exports all functions from the L</-contraints>,
+L</-isas>, and L</-nots> export groups and the functionality provided by the
+L</-attr> tag.
+
 =head2 -nots
 
 The nots export group exports all functions which have the C<not_> prefix. These
 functions take a single argument and perform non-fatal negated type checking and
-return true or false. The follow is a list of functions exported by this group:
+return true or false. The following is a list of functions exported by this
+group:
 
 =over 4
 
@@ -1019,7 +1184,7 @@ type_undefined
 
 The typesof export group exports all functions which have the C<typeof_> prefix.
 These functions take no argument and return a type-validation code-routine to be
-used with your object-system of choice. The follow is a list of functions
+used with your object-system of choice. The following is a list of functions
 exported by this group:
 
 =over 4
@@ -1166,7 +1331,7 @@ typeof_undefined
 
 The utils export group exports all miscellaneous utility functions, e.g. file,
 path, date, etc. Many of these functions are wrappers around standard CPAN
-modules. The follow is a list of functions exported by this group:
+modules. The following is a list of functions exported by this group:
 
 =over 4
 
